import React from 'react';
import cx from 'classnames';
var CELL_TYPE = {
  header: 'th',
  data: 'td'
};
var CELL_PADDING = {
  xs: 'xs',
  s: 's',
  m: 'm',
  l: 'l',
  xl: 'l'
};

var AtomTable = function AtomTable(_ref) {
  var _cx, _cx2, _cx3;

  var head = _ref.head,
      body = _ref.body,
      foot = _ref.foot,
      fullWidth = _ref.fullWidth,
      cellPadding = _ref.cellPadding,
      borderBottom = _ref.borderBottom,
      onRowClick = _ref.onRowClick;
  var hasHead = Boolean(head == null ? void 0 : head.length);
  var hasFoot = Boolean(foot == null ? void 0 : foot.length);
  var isRowActionable = Boolean(onRowClick);
  var baseClass = 'react-AtomTable';
  var tableClass = cx("" + baseClass, (_cx = {}, _cx[baseClass + "--fullWidth"] = Boolean(fullWidth), _cx));
  var headerClass = cx(baseClass + "-cell", baseClass + "-headerCell", (_cx2 = {}, _cx2[baseClass + "-cell--" + cellPadding] = Boolean(cellPadding), _cx2));
  var rowClass = cx(baseClass + "-row", (_cx3 = {}, _cx3[baseClass + "-row--actionable"] = isRowActionable, _cx3));

  var handleOnRowClick = function handleOnRowClick(index) {
    return onRowClick(index);
  };

  return /*#__PURE__*/React.createElement("table", {
    className: tableClass
  }, hasHead && /*#__PURE__*/React.createElement("thead", null, /*#__PURE__*/React.createElement("tr", null, head.map(function (element, index) {
    return /*#__PURE__*/React.createElement("th", {
      key: index,
      className: headerClass
    }, element);
  }))), /*#__PURE__*/React.createElement("tbody", null, body.map(function (row, index) {
    return /*#__PURE__*/React.createElement("tr", Object.assign({
      key: index,
      className: rowClass
    }, isRowActionable && {
      onClick: function onClick() {
        return handleOnRowClick(index);
      }
    }), row.map(function (cell, index) {
      var _cx4;

      var _cell$type = cell.type,
          Element = _cell$type === void 0 ? CELL_TYPE.data : _cell$type,
          _cell$content = cell.content,
          content = _cell$content === void 0 ? '' : _cell$content,
          isNowrap = cell.isNowrap,
          _cell$colspan = cell.colspan,
          colspan = _cell$colspan === void 0 ? 1 : _cell$colspan;
      var cellClassName = cx(baseClass + "-cell", (_cx4 = {}, _cx4[baseClass + "-cell--noWrap"] = isNowrap, _cx4[baseClass + "-cell--" + cellPadding] = Boolean(cellPadding), _cx4[baseClass + "-cell--borderBottom"] = Boolean(borderBottom), _cx4));
      return /*#__PURE__*/React.createElement(Element, {
        key: index,
        className: cellClassName,
        colSpan: colspan
      }, content);
    }));
  })), hasFoot && /*#__PURE__*/React.createElement("tfoot", null, /*#__PURE__*/React.createElement("tr", null, foot.map(function (element, index) {
    return /*#__PURE__*/React.createElement("td", {
      key: index,
      className: baseClass + "-cell"
    }, element);
  }))));
};

AtomTable.displayName = 'AtomTable';
export { CELL_TYPE as atomTableCellTypes, CELL_PADDING as atomTableCellPadding };
export default AtomTable;